==> kports-0.6.0.tar.bz2: kports-0.6.0/src/installwizard.h <==
/***************************************************************************
 *   Copyright (C) 2005, 2006 by Hannes Hauswedell                         *
 *   hannes.hauswedell@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef INSTALLWIZARD_H
#define INSTALLWIZARD_H

#include <qbrush.h>
#include <qcolor.h>
#include <qlineedit.h>
#include <qradiobutton.h>
#include <qlabel.h>
#include <qmovie.h>
#include <qslider.h>
#include <qscrollbar.h>
#include <qstringlist.h>
#include <qtooltip.h>
#include <qwidgetstack.h>
#include <qtable.h>
#include <qheader.h>
#include <qbuttongroup.h>

#include <kprogress.h>
#include <ktextedit.h>
#include <kurllabel.h>

#include "bsdport.h"
#include "kportsview.h"
#include "installwizardbase.h"
#include "kportspopups.h"

class InstallWizard;
class KPortsView;
class QBsdPort;


class QPortLink : public KURLLabel
{
Q_OBJECT
/**
this class is only used so that i can insert buttons into the tables
that upon being clicked emit the port they represent together with
the click event. since this wont be used anywhere else all implement-
ations are done inline **/
private:
	QBsdPort	*port;

public:
	QPortLink(QWidget *parent = 0, const char *name = 0, QBsdPort *Port = 0)
		: KURLLabel(parent, name)
	{ 
		port = Port; 
		connect(this, SIGNAL(leftClickedURL()), this, SLOT(click2port()));
//		QPushButton(parent, name);
	}
	
	~QPortLink() {}



public slots:
	void click2port() { emit clickedPort(port); }
signals:
	void clickedPort(QBsdPort*);

};

class InstallWizard : public InstallWizardBase 
{
Q_OBJECT

public:

	InstallWizard(QWidget *parent = 0, const char *name = 0, int goal);
	/// goal = 0 ->uninstall , 1 -> install, 2 -> upgrade everything
	InstallWizard();
	~InstallWizard();


	KPortsView 	*mParent;

	QTimer		*timer;

private:
	
   	QBsdPort	*port;
	
    	int		aim,//-1 = uninstall, 0 = frsh install, 1 = upgrade, 2 = downgrade, 3 = reinstall 
			recursive;
	bool		ignore;
   	QListViewItem	*tmpitem;
	QString		label[4];
	int 		progress;
	bool 		forward;
	bool		wasInterupted;
	int		binsource;
			///0 = source, 1 = bin, 2= bin + src (portupgrade -P)
	bool		realBIN; ///is neccessary sine binsource = 2 doesnt say wehther main port is installed binary or not 

	QSignalMapper	*mapper1, *mapper2;
	QFile		*logFile;

	
	struct		_portInView
	{
		QBsdPort* p; 	/// pointer to port
		bool	bin;	/// binary or not
		QString	env;	/// non-default environment
		bool	finished;
		QString	errors;
		int	line; /// is equal to position in list
	};
	
	QPtrList <_portInView>	portsInView;
		
	
	QColor		backgroundColor;


//	void customEvent(QCustomEvent* event);

	void		addPortToOverview(QBsdPort *Port, int type); 
			//type 0 = main port, 1 = dep, 2 = revdep

	void 		updateOverview();
	
	
	
	bool		warningGiven; /// warn user that kports produces no info for pkgsystem == freebsd ports without portupgrade
	QBsdPort	*currentPort;
	int		currentRow;
	bool		awaitingResults;
	bool		show2arrow;

public slots:
    virtual void CommitPressed();
    virtual void cIgnoreToggled();
    virtual void cUpgradeDepsToggled();
	void 	progression();
	void 	warningPushed(QBsdPort*);
	void 	optionsPushed(QBsdPort*);
	void	failedPushed(QBsdPort*);
	void	messagePushed(QBsdPort*);
    virtual void modeChanged();
    void	addWarning(int);
    void	addOptions(int);
    void	saveASignal(int);
    virtual void bViewReqsClicked();
    virtual void bViewDepsClicked();
    virtual void showKonsole(bool);
    
    void	stdOutReceived(QString);
    void	stdErrReceived(QString);
    void	installProcFinished();
    void	installCmdReceived(QString);

    void	resizeIcon();
    void	updateIcon();
    
    void	updateLWItemsInParent(QBsdPort*);
};


#endif

==> kports-0.6.1.tar.bz2: kports-0.6.1/src/installwizard.h <==
/***************************************************************************
 *   Copyright (C) 2005, 2006 by Hannes Hauswedell                         *
 *   hannes.hauswedell@gmail.com                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef INSTALLWIZARD_H
#define INSTALLWIZARD_H

#include <qbrush.h>
#include <qcolor.h>
#include <qlineedit.h>
#include <qradiobutton.h>
#include <qlabel.h>
#include <qmovie.h>
#include <qslider.h>
#include <qscrollbar.h>
#include <qstringlist.h>
#include <qtooltip.h>
#include <qwidgetstack.h>
#include <qtable.h>
#include <qheader.h>
#include <qbuttongroup.h>

#include <kprogress.h>
#include <ktextedit.h>
#include <kurllabel.h>

#include "bsdport.h"
#include "kportsview.h"
#include "installwizardbase.h"
#include "kportspopups.h"

class InstallWizard;
class KPortsView;
class QBsdPort;


class QPortLink : public KURLLabel
{
Q_OBJECT
/**
this class is only used so that i can insert buttons into the tables
that upon being clicked emit the port they represent together with
the click event. since this wont be used anywhere else all implement-
ations are done inline **/
private:
	QBsdPort	*port;

public:
	QPortLink(QWidget *parent = 0, const char *name = 0, QBsdPort *Port = 0)
		: KURLLabel(parent, name)
	{ 
		port = Port; 
		connect(this, SIGNAL(leftClickedURL()), this, SLOT(click2port()));
//		QPushButton(parent, name);
	}
	
	~QPortLink() {}



public slots:
	void click2port() { emit clickedPort(port); }
signals:
	void clickedPort(QBsdPort*);

};

class InstallWizard : public InstallWizardBase 
{
Q_OBJECT

public:

	InstallWizard(QWidget *parent = 0, const char *name = 0, int goal = 1);
	/// goal = 0 ->uninstall , 1 -> install, 2 -> upgrade everything
	InstallWizard();
	~InstallWizard();


	KPortsView 	*mParent;

	QTimer		*timer;

private:
	
   	QBsdPort	*port;
	
    	int		aim,//-1 = uninstall, 0 = frsh install, 1 = upgrade, 2 = downgrade, 3 = reinstall 
			recursive;
	bool		ignore;
   	QListViewItem	*tmpitem;
	QString		label[4];
	int 		progress;
	bool 		forward;
	bool		wasInterupted;
	int		binsource;
			///0 = source, 1 = bin, 2= bin + src (portupgrade -P)
	bool		realBIN; ///is neccessary sine binsource = 2 doesnt say wehther main port is installed binary or not 

	QSignalMapper	*mapper1, *mapper2;
	QFile		*logFile;

	
	struct		_portInView
	{
		QBsdPort* p; 	/// pointer to port
		bool	bin;	/// binary or not
		QString	env;	/// non-default environment
		bool	finished;
		QString	errors;
		int	line; /// is equal to position in list
	};
	
	QPtrList <_portInView>	portsInView;
		
	
	QColor		backgroundColor;


//	void customEvent(QCustomEvent* event);

	void		addPortToOverview(QBsdPort *Port, int type); 
			//type 0 = main port, 1 = dep, 2 = revdep

	void 		updateOverview();
	
	
	
	bool		warningGiven; /// warn user that kports produces no info for pkgsystem == freebsd ports without portupgrade
	QBsdPort	*currentPort;
	int		currentRow;
	bool		awaitingResults;
	bool		show2arrow;

public slots:
    virtual void CommitPressed();
    virtual void cIgnoreToggled();
    virtual void cUpgradeDepsToggled();
	void 	progression();
	void 	warningPushed(QBsdPort*);
	void 	optionsPushed(QBsdPort*);
	void	failedPushed(QBsdPort*);
	void	messagePushed(QBsdPort*);
    virtual void modeChanged();
    void	addWarning(int);
    void	addOptions(int);
    void	saveASignal(int);
    virtual void bViewReqsClicked();
    virtual void bViewDepsClicked();
    virtual void showKonsole(bool);
    
    void	stdOutReceived(QString);
    void	stdErrReceived(QString);
    void	installProcFinished();
    void	installCmdReceived(QString);

    void	resizeIcon();
    void	updateIcon();
    
    void	updateLWItemsInParent(QBsdPort*);
};


#endif
